@@ -1,9 +1,8 @@
 package Class::PObject::Driver::DBM;
 
-# $Id: DBM.pm,v 1.8 2003/09/09 00:11:54 sherzodr Exp $
+# $Id: DBM.pm,v 1.3 2003/08/24 20:51:25 sherzodr Exp $
 
 use strict;
-#use diagnostics;
 use Carp;
 use Class::PObject::Driver;
 use File::Spec;
@@ -12,7 +11,7 @@ use vars ('$VERSION', '@ISA', '$lock');
 
 @ISA = ('Class::PObject::Driver');
 
-$VERSION = '2.00';
+$VERSION = '1.00';
 
 
 sub save {
@@ -23,17 +22,20 @@ sub save {
         my $lastid = $dbh->{_lastid} || 0;
         $columns->{id} = ++$dbh->{_lastid}
     }
-    $dbh->{ "!ID:" . $columns->{id} } = $self->freeze($object_name, $properties, $columns);
+    $dbh->{ "!ID:" . $columns->{id} } = $self->freeze($columns);
     $unlock->();
     return $columns->{id}
 }
 
 
 
-sub load_ids {
+sub load {
     my ($self, $object_name, $properties, $terms, $args) = @_;
 
     my (undef, $dbh, $unlock) = $self->dbh($object_name, $properties) or return undef;
+    if ( $terms && (ref($terms) ne 'HASH') && ($terms =~ /^\d+$/) ) {
+        return [$self->thaw( $dbh->{"!ID:" . $terms} )]
+    }
     my @data_set = ();
     my $n = 0;
     while ( my ($k, $v) = each %$dbh ) {
@@ -41,17 +43,13 @@ sub load_ids {
             $n++ == $args->{limit} and last
         }
         $k =~ /!ID:/ or next;
-        my $data = $self->thaw( $object_name, $properties, $v );
+        my $data = $self->thaw( $v );
         if ( $self->_matches_terms($data, $terms) ) {
-            push @data_set, keys %$args ? $data : $data->{id}
+            push @data_set, $data
         }
     }
     $unlock->();
-    unless ( keys %$args ) {
-        return \@data_set
-    }
-    my $data = $self->_filter_by_args(\@data_set, $args);
-    return [ map { $_->{id} } @$data ]
+    return $self->_filter_by_args(\@data_set, $args)
 }
 
 
@@ -59,28 +57,6 @@ sub load_ids {
 
 
 
-sub load {
-    my ($self, $object_name, $props, $id) = @_;
-
-    my (undef, $dbh, $unlock) = $self->dbh($object_name, $props) or return undef;
-    return $self->thaw($object_name, $props, $dbh->{ "!ID:" . $id })
-}
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 
 
 sub remove {
@@ -140,6 +116,7 @@ sub _lock {
 
 1;
 __END__
+# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -202,33 +179,25 @@ on the C<$lock_type>, which can be either of I<w> or I<r>.
 
 Returns a reference to an action (subroutine), which perform unlocking for this particular
 lock. On failure returns undef. C<_lock()> is usually called from within C<dbh()>, and return
-value is returned together with database handles.
+value is returned together with database hadnles.
 
 =back
 
-=head1 NOTES
-
-Currently the only record index is the I<id> column. By introducing configurable indexes,
-object selections (through C<load()> method) can be improved tremendously. Syntax similar 
-to the following may suffice:
-
-    pobject Article => {
-        columns         => ['id', 'title', 'author', 'content'],
-        indexes         => ['title', 'author'],
-        driver          => 'db_file',
-        datasource      => './data'
-    }
-        
-This issue is to be addressed in subsequent releases.
-
 =head1 SEE ALSO
 
 L<Class::PObject::Driver>,
 L<Class::PObject::Driver::DB_File>
 L<Class::PObject::Driver::DBI>
 
+=head1 AUTHOR
+
+Sherzod B. Ruzmetov, E<lt>sherzodr@cpan.orgE<gt>, http://author.handalak.com/
+
 =head1 COPYRIGHT AND LICENSE
 
-For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
+Copyright 2003 by Sherzod B. Ruzmetov.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 
 =cut
