@@ -1,9 +1,9 @@
 package Class::PObject::Driver::csv;
 
-# $Id: csv.pm,v 1.20 2003/11/07 04:51:04 sherzodr Exp $
+# $Id: csv.pm,v 1.10 2003/08/23 10:36:44 sherzodr Exp $
 
 use strict;
-#use diagnostics;
+use Carp;
 use Log::Agent;
 use File::Spec;
 use vars ('$VERSION', '@ISA');
@@ -11,9 +11,6 @@ use vars ('$VERSION', '@ISA');
 require Class::PObject::Driver::DBI;
 @ISA = ('Class::PObject::Driver::DBI');
 
-$VERSION = '2.01';
-
-
 
 sub save {
     my $self = shift;
@@ -27,26 +24,32 @@ sub save {
 
     my $dbh   = $self->dbh($object_name, $props)                or return;
     my $table = $self->_tablename($object_name, $props, $dbh)   or return;
-    my ($sql, $bind_params);
   
     my $exists = $self->count($object_name, $props, {id=>$columns->{id}});
     if ( $exists ) {
-        ($sql, $bind_params) = $self->_prepare_update($table, $columns, {id=>$columns->{id}});
-
+        my ($sql, $bind_params) = $self->_prepare_update($table, $columns, {id=>$columns->{id}});
+        my $sth = $dbh->prepare( $sql );
+        unless( $sth->execute(@$bind_params) ) {
+            $self->error("couldn't execute '$sth->{Statement}': " . $sth->errstr);
+            return undef
+        }
     } else {
-        ($sql, $bind_params) = $self->_prepare_insert($table, $columns);
-        
-    }
-    my $sth = $dbh->prepare( $sql );
-    unless ( $sth->execute( @$bind_params )  ) {
-        $self->errstr( "Failed query ($sth->{Statement}): " . $sth->errstr );
-        return undef
+        my ($sql, $bind_params) = $self->_prepare_insert($table, $columns);
+        my $sth = $dbh->prepare( $sql );
+        unless($sth->execute(@$bind_params)) {
+            $self->error("couldn't execute query '$sth->{Statement}': " . $sth->errstr);
+            return undef
+        }
     }
     return $columns->{id}
 }
 
 
 
+
+
+
+
 sub generate_id {
     my ($self, $object_name, $props) = @_;
 
@@ -59,10 +62,11 @@ sub generate_id {
 
 
 
+
+
 sub dbh {
     my $self = shift;
-    my ($object_name) = @_;
-    my $props = $object_name->__props();
+    my ($object_name, $props) = @_;
 
     if ( defined $props->{datasource}->{Handle} ) {
         return $props->{datasource}->{Handle}->{Name}
@@ -77,12 +81,11 @@ sub dbh {
 
     require DBI;
     
-    my $dbh = DBI->connect("DBI:CSV:f_dir=$dir", "", "", {RaiseError=>1, PrintError=>1});
+    my $dbh = DBI->connect("DBI:CSV:f_dir=$dir");
     unless ( defined $dbh ) {
         $self->error($DBI::errstr);
         return undef
     }
-    $dbh->{FetchHashKeyName} = 'NAME_lc';
     $self->stash($stashed_name, $dbh);
     $self->stash('close', 1);
     return $dbh
@@ -111,18 +114,29 @@ sub _dir {
 
 
 
+
+
+
+
 sub _tablename {
     my ($self, $object_name, $props, $dbh) = @_;
 
     my $table = $self->SUPER::_tablename($object_name, $props);
+
     my $dir   = $self->_dir($props) or return;
     if ( -e File::Spec->catfile($dir, $table) ) {
         return $table
     }
 
-    my $sql = $self->_prepare_create_table($object_name, $table);
-    unless( $dbh->do( $sql ) ) {
-        $self->errstr( $dbh->errstr );
+    my @sets    = ();
+    for my $colname ( @{$props->{columns}} ) {
+        push @sets, "$colname BLOB";
+    }
+
+    my $sql_str = sprintf("CREATE TABLE %s (%s)", $table, join (", ", @sets));
+    my $sth = $dbh->prepare($sql_str);
+    unless($sth->execute()) {
+        $self->error($sth->{Statement} . ': ' . $sth->errstr);
         return undef
     }
     return $table
@@ -130,16 +144,6 @@ sub _tablename {
 
 
 
-sub _prepare_create_table {
-    my $self = shift;
-
-    my $sql = $self->SUPER::_prepare_create_table( @_ );
-    $sql =~ s/(NOT\s+)?NULL//ig;
-    return $sql
-}
-
-
-
 1;
 __END__
 # Below is stub documentation for your module. You'd better edit it!
@@ -176,8 +180,7 @@ I<datasource> attribute should be in the form of a hashref. The following keys a
 =item *
 
 C<Dir> - points to the directory where the CSV files are stored. If this is missing
-will default to your system's temporary folder. If the Dir is provided, and it doesn't
-exist, it will be created for you.
+will default to your system's temporary folder.
 
 =item *
 
@@ -219,35 +222,20 @@ for you.
 
 =back
 
-=head1 NOTES
-
-If the table is detected to be missing in the database, it will attempt to create proper
-table for you. To have more control over how it creates this table,
-you can fill-in column types using I<tmap> argument.
-
-
-=head2 SPEED
-
-I<csv> driver can get incredibly processor intensive once the number of records exceeds
-1,000. This can be fixed by providing indexing functionality to the driver, which it currently
-misses.
-
-Main issue of the driver is in its C<save()> method, where it first needs to SELECT the records
-to find out if the record being inserted exists or not. Then, depending on its discoveries
-either runs INSERT or UPDATE queries.
-
-C<generate_id()> method could also be improved by allowing it to keep track of record count
-in a separate file.
-
-All these issues need to be addressed in subsequent releases of the library.
-
 =head1 SEE ALSO
 
 L<Class::PObject>, L<Class::PObject::Driver::mysql>,
 L<Class::PObject::Driver::file>
 
+=head1 AUTHOR
+
+Sherzod Ruzmetov E<lt>sherzodr@cpan.orgE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
-For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
+Copyright 2003 by Sherzod B. Ruzmetov.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 
 =cut
