@@ -1,15 +1,13 @@
 package Class::PObject::Driver::mysql;
 
-# $Id: mysql.pm,v 1.25 2003/12/12 05:17:37 sherzodr Exp $
+# $Id: mysql.pm,v 1.17 2003/08/23 14:31:29 sherzodr Exp $
 
 use strict;
-#use diagnostics;
 use Log::Agent;
-use vars ('@ISA', '$VERSION');
+use vars qw(@ISA $VERSION);
 require Class::PObject::Driver::DBI;
 
 @ISA = ('Class::PObject::Driver::DBI');
-$VERSION = '2.01';
 
 # 
 # overriding _prepare_insert() with the version that uses REPLACE
@@ -21,9 +19,10 @@ sub _prepare_insert {
     my ($sql, @fields, @bind_params);
     $sql = "REPLACE INTO $table_name SET ";
     while ( my ($k, $v) = each %$columns ) {
-        push @fields, "`$k`=?";
+        push @fields, "$k=?";
         push @bind_params, $v
     }
+
     $sql .= join(", ", @fields);
     return ($sql, \@bind_params)
 }
@@ -36,10 +35,11 @@ sub save {
     my ($self, $object_name, $props, $columns) = @_;
     
     my $dbh                 = $self->dbh($object_name, $props)        or return;
-    my $table               = $self->_tablename($object_name, $props, $dbh) or return;
+    my $table               = $self->_tablename($object_name, $props) or return;
     my ($sql, $bind_params) = $self->_prepare_insert($table, $columns);
 
     $self->_write_lock($dbh, $table) or return undef;
+
     my $sth                 = $dbh->prepare( $sql );
     unless ( $sth->execute(@$bind_params) ) {
         $self->errstr("couldn't save/update the record: " . $sth->errstr);
@@ -67,31 +67,36 @@ sub dbh {
         $self->errstr("'datasource' is invalid");
         return undef
     }
+
     if ( defined $props->{datasource}->{Handle} ) {
         return $props->{datasource}->{Handle}
     }
+  
     my $stashed_name = $props->{datasource}->{DSN};
     if ( defined $self->stash($stashed_name) ) {
         return $self->stash($stashed_name)
     }
+  
     if ( $datasource->{Handle} ) {
         $self->stash($stashed_name, $datasource->{Handle});
         return $datasource->{Handle}
     }
+  
     my $dsn       = $datasource->{DSN};
     my $db_user   = $datasource->{User} || $datasource->{UserName};
     my $db_pass   = $datasource->{Password};
+
     unless ( $dsn ) {
         $self->errstr("'DSN' is missing in 'datasource'");
         return undef
     }
+  
     require DBI;
     my $dbh = DBI->connect($dsn, $db_user, $db_pass, {RaiseError=>1, PrintError=>0});
     unless ( defined $dbh ) {
         $self->errstr("couldn't connect to 'DSN': " . $DBI::errstr);
         return undef
     }
-    $dbh->{FetchHashKeyName} = 'NAME_lc';
     $self->stash($stashed_name, $dbh);
     $self->stash('close', 1);
     return $dbh
@@ -99,59 +104,13 @@ sub dbh {
 
 
 
-sub _tablename {
-    my $self = shift;
-    my ($object_name, $props, $dbh) = @_;
-
-    unless ( defined $dbh ) {
-        $dbh = $self->dbh( $object_name, $props )
-    }
-    my $tablename   = $self->SUPER::_tablename(@_);
-    my $exists= 0;
-    # if table by this name already exists in the database,
-    # no reason to go any further.Return the name
-    my $stashed = sprintf "exists:%s-%s", $dbh->{Name}, $tablename;
-    if ( $self->stash($stashed) ) {
-        logtrc 3, "'$stashed' was present. Table exists";
-        return $tablename
-    }
-    
-    # if we come this far, we're still not sure if the database 
-    # exists or not. so we peek into the catalog.
-    my %tables  = map { s/\W//g; $_, 1 } $dbh->tables;
-    logtrc 3, "Retrieved %d tables from the database", scalar keys %tables;
-    if ( $tables{ $tablename } ) {
-        logtrc 3, "Table '%s' exists", $tablename;
-        $self->stash($stashed, 1);
-        return $tablename
-    }
-
-    my $sql = $self->_prepare_create_table($object_name, $tablename);
-    unless ( $dbh->do( $sql ) ) {
-        $self->errstr( $dbh->errstr );
-        return undef
-    }
-    $self->stash($stashed, 1);
-    return $tablename
-}
-
-
-
-sub _prepare_create_table {
-    my ($self, $object_name, $tablename) = @_;
-
-    my $sql = $self->SUPER::_prepare_create_table($object_name, $tablename);
-    $sql =~ s/(id +INTEGER +PRIMARY +KEY)/$1 AUTO_INCREMENT/i;
-    return $sql
-}
-
-
-
 
 
 1;
 __END__;
 
+=pod
+
 =head1 NAME
 
 Class::PObject::Driver::mysql - MySQL Pobject Driver
@@ -235,19 +194,20 @@ that MySQL will take care of creating auto-incrementing unique object ids for yo
 
 =back
 
-=head1 NOTES
-
-If the table is detected to be missing in the database, it will attempt to create proper
-table for you. To have more control over how it creates this table,
-you can fill-in column types using I<tmap> argument.
-
 =head1 SEE ALSO
 
 L<Class::PObject>, L<Class::PObject::Driver::csv>,
 L<Class::PObject::Driver::file>
 
+=head1 AUTHOR
+
+Sherzod Ruzmetov E<lt>sherzodr@cpan.orgE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
-For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
+Copyright 2003 by Sherzod B. Ruzmetov.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 
 =cut
