@@ -1,21 +1,19 @@
 package Class::PObject::Test::Basic;
 
-# $Id: Basic.pm,v 1.12 2003/11/07 00:28:24 sherzodr Exp $
-
 use strict;
-#use diagnostics;
+use warnings;
 use Test::More;
 use Class::PObject;
 use Class::PObject::Test;
+
 use vars ('$VERSION', '@ISA');
-use overload;
 
 @ISA = ('Class::PObject::Test');
-$VERSION = '1.02';
+$VERSION = '1.00';
 
 
 BEGIN {
-    plan(tests => 173);
+    plan(tests => 137);
     use_ok("Class::PObject")
 }
 
@@ -23,23 +21,18 @@ BEGIN {
 sub run {
     my $self = shift;
 
-    pobject 'PO::Author' => {
+    pobject PO::Author => {
         columns     => ['id', 'name', 'url', 'email'],
         driver      => $self->{driver},
-        datasource  => $self->{datasource},
-        serializer  => 'storable',
-        tmap        => {
-            name => 'VARCHAR(40)'
-        }
+        datasource  => $self->{datasource}
     };
     ok(1);
 
 
-    pobject 'PO::Article' => {
+    pobject PO::Article => {
         columns     => ['id', 'title', 'author', 'content', 'rating'],
         driver      => $self->{driver},
-        datasource  => $self->{datasource},
-        serializer  => 'storable'
+        datasource  => $self->{datasource}
     };
     ok(1);
 
@@ -61,56 +54,29 @@ sub run {
         }
     }
 
-    ################
-    #
-    # Testing for the values of @ISA
-    #
-    ok($PO::Author::ISA[0] eq "Class::PObject::Template");
-    ok($PO::Article::ISA[0] eq "Class::PObject::Template");
-    
-
     ####################
     #
     # 3. Creating new objects
     #
     my $author1 = new PO::Author();
-    ok(ref $author1);
+    ok($author1);
 
     my $author2 = new PO::Author();
-    ok(ref $author2);
+    ok($author2);
 
     my $author3 = new PO::Author(name=>"Geek", email=>'sherzodr@cpan.org');
-    ok(ref $author3);
+    ok($author3);
+
 
 
     my $article1 = new PO::Article();
-    ok(ref $article1);
+    ok($article1);
 
     my $article2 = new PO::Article();
-    ok(ref $article2);
+    ok($article2);
 
     my $article3 = new PO::Article();
-    ok(ref $article3);
-
-
-    ################
-    #
-    # Testing if our object is a 'Class::PObject::Template'
-    #
-    ok($author1->isa('Class::PObject::Template') && $author2->isa('Class::PObject::Template') &&
-                                                    $article1->isa('Class::PObject::Template'));
-
-    ################
-    #
-    # Testing if overloading is applicable
-    # to these particular objects
-    #
-    ok(overload::Overloaded($author1));
-    ok(overload::Overloaded($author2));
-    ok(overload::Overloaded($author3));
-    ok(overload::Overloaded($article1));
-    ok(overload::Overloaded($article2));
-    ok(overload::Overloaded($article3));
+    ok($article3);
 
     ####################
     #
@@ -120,7 +86,6 @@ sub run {
     ok(ref($author1->columns) eq 'HASH');
     ok(ref($author1->__props) eq 'HASH');
     ok(ref($author1->__driver) eq 'Class::PObject::Driver::' . $self->{driver});
-    
 
     ####################
     #
@@ -128,11 +93,8 @@ sub run {
     #
     ok($author1->can('id') && $author2->can('name') && $author3->can('email'));
     ok($author1->name ? 0 : 1);
-    #ok(1);
-    
 
     ok($article1->can('id') && $article2->can('title') && $article3->can('author'));
-    #exit;
 
     ####################
     #
@@ -142,19 +104,13 @@ sub run {
     $author1->url('http://author.handalak.com/');
     $author1->email('sherzodr@cpan.org');
 
-    my $name = $author1->name();
-    ok($name->isa("Class::PObject::Type"));
-    ok($name eq "Sherzod Ruzmetov");
-
     ok($author1->name eq "Sherzod Ruzmetov");
     ok($author1->email eq 'sherzodr@cpan.org');
     
     $author1->name(undef);
 
     ok($author1->name ? 0 : 1);
-    #ok($author1->{_is_new} == 1);
-    ok(1);
-    #exit;
+    ok($author1->{_is_new} == 1);
 
     $author2->name("Hilola Nasyrova");
     $author2->url('http://hilola.handalak.com/');
@@ -188,12 +144,8 @@ sub run {
     $article1->author($author1_id);
 
     my $article1_id = undef;
-    print $article1->dump;
     ok($article1_id = $article1->save);
 
-    ok($article1_id == $article1->id);
-    ok($article1    == $article1_id);
-
     undef($author1);
     undef($author2);
     undef($article1);
@@ -245,15 +197,6 @@ sub run {
     }
     @authors = undef;
 
-
-
-    ################
-    #
-    # FIX: if load(0) was treated the same way as load()
-    #
-    my $author4 = PO::Author->load(0);
-    ok(!$author4);
-
     ####################
     #
     # 11. Loading object(s) in array context with terms
@@ -348,6 +291,8 @@ sub run {
 
 
 
+
+
     @authors = ();
     @authors = PO::Author->load(undef, {'sort'=>'id', direction=>'desc', limit=>1});
     ok(@authors == 1);
@@ -434,37 +379,11 @@ sub run {
     ok($authors[0]->name eq "Sherzod Ruzmetov");
 
 
-    ###################
-    #
-    # Checking the iterator
-    #
-    my $iterator = PO::Author->fetch(undef, {'sort'=>'name'});
-    #die $iterator->dump;
-    ok( $iterator->size == 3);
-    #die $iterator->size;
-    ok(ref $iterator eq "Class::PObject::Iterator");
-    $author1 = $iterator->next();
-    ok(ref $author1 eq "PO::Author");
-    ok( $author1->name eq "Geek");
 
-    $author2 = $iterator->next();
-    ok( ref $author2 eq "PO::Author");
-    ok( $author2->name eq "Hilola Nasyrova");
 
-    ok( $iterator->size == 1);
 
-    # trying to iterate through the list. We should
-    # have only one object left, since we already called next() two times:
-    while ( my $author = $iterator->next ) {
-        ok( $author->name eq "Sherzod Ruzmetov" );
-    }
 
-    # now we need to reset the pointers:
-    $iterator->reset();
 
-    while ( my $author = $iterator->next ) {
-        ok( ref $author eq "PO::Author");
-    }
 
 
     ####################
@@ -473,27 +392,15 @@ sub run {
     # can start with brand new scratch board
     #
 
-    $iterator->reset();
-    my $author = $iterator->next;
-
-    # removing author named 'Geek':
-    ok($author->remove, $author->errstr);
-
-    ok(PO::Author->count == 2, "count: " . PO::Author->count);
-
-    # again trying to remove the author 'Geek'. This should have no
-    # effect, since it's been removed in previous query
     ok(PO::Author->remove_all({name=>"Geek"}));
-    # we still should have two objects in total in our database
-    ok(PO::Author->count == 2, "count: " . PO::Author->count);
+    ok(PO::Author->count == 2);
     ok(PO::Author->remove_all);
     ok(PO::Author->count == 0);
 
     ok(PO::Article->remove_all);
-    ok(PO::Article->count == 0);
-    
-    ok(PO::Article->drop_datasource);
-    ok(PO::Author->drop_datasource);
+    ok(PO::Article->count == 0)
+    #ok(1);
+    #ok(1);
 }
 
 
@@ -519,6 +426,11 @@ Class::PObject::Test::Basic - Class::PObject's basic test suit
     $t = new Class::PObject::Test::Basic($drivername, $datasource);
     $t->run() # running the tests
 
+=head1 ABSTRACT
+
+    Class::PObject::Test::Basic is a subclass of Class::PObject::Test::Basic,
+    and is used for running basic tests for a specific driver.
+
 =head1 DESCRIPTION
 
 This library is particularly useful for Class::PObject driver authors. It provides
@@ -526,22 +438,70 @@ a convenient way of testing your newly created PObject driver to see if it funct
 properly, as well as helps you to write test scripts with literally couple of lines
 of code.
 
-This same class is also used by L<Class::PObject|Class::PObject>'s standard test scripts
-
-Class::PObject::Test::Basic is a subclass of L<Class::PObject::Test|Class::PObject::Test>.
+Class::PObject::Test::Basic is a subclass of L<Class::PObject::Test>.
 
 =head1 NATURE  OF TESTS
 
-This test suite tests the driver's ability to perform most of the functionality
-as discussed in Class::PObject's L<manual|Class::PObject>.
+Class::POBject::Test::Basic runs tests to check following aspects of the driver:
+
+=over 4
+
+=item *
+
+C<pobject> declarations.
+
+=item *
+
+Creating and initializing pobject instances
+
+=item *
+
+Proper functionality of the accessor methods and integrity of in-memory data
+
+=item *
+
+Synchronization of in-memory data into disk
+
+=item *
+
+If basic load() performs as expected, in both array and scalar context.
+
+=item *
+
+Checking the integrity of synchronized disk data
+
+=item *
+
+Checking for count() - both simple syntax, and count(\%terms) syntax.
+
+=item *
+
+Checking different combinations of C<load(undef, \%args)>, C<load(\%terms, undef)>,
+C<load(\%terms, \%args)>
+
+=item *
+
+Checking if objects can be removed off the disk successfully
+
+=back
+
+In addition to the above tests, Class::PObject::Test::Basic also address such issues
+as I<multiple instances of the same object> as well as I<multiple classes and multiple objects>
+cases, which have been major sources for bugs for L<Class::PObject> drivers.
 
 =head1 SEE ALSO
 
-L<Class::PObject::Test::Types>,
-L<Class::PObject::Test::HAS_A>
+L<Class::PObject::Test>, L<Class::PObject>, L<Class::PObject::Driver>
+
+=head1 AUTHOR
+
+Sherzod B. Ruzmetov, E<lt>sherzodr@cpan.orgE<gt>, http://author.handalak.com/
 
 =head1 COPYRIGHT AND LICENSE
 
-For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
+Copyright 2003 by Sherzod B. Ruzmetov.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
